@@ -1,5 +1,5 @@
 package Treex::Core::DocumentReader::Base;
-$Treex::Core::DocumentReader::Base::VERSION = '2.20151210';
+$Treex::Core::DocumentReader::Base::VERSION = '2.20151216';
 use Moose;
 use Treex::Core::Common;
 with 'Treex::Core::DocumentReader';
@@ -215,3 +215,33 @@ sub fill_bundle_zone {
 
 1;
 
+__END__
+
+=encoding utf-8
+
+=head1 NAME
+
+Treex::Core::DocumentReader::Base - base implementation of document readers
+
+=head1 VERSION
+
+version 2.20151216
+
+=head1 DESCRIPTION
+
+Base implementation of L<Treex::Core::DocumentReader>.
+Experimental code, not used so far.
+
+=head1 METHODS
+
+TODO
+
+=head1 AUTHOR
+
+Martin Popel <popel@ufal.mff.cuni.cz>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
+
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
